summaryrefslogtreecommitdiffstats
path: root/server
diff options
context:
space:
mode:
authorLeif Åstrand <leif@vaadin.com>2013-04-22 08:56:42 +0300
committerLeif Åstrand <leif@vaadin.com>2013-04-22 08:58:38 +0300
commit277adf6142a4fa51a0aba42d9934ac0c0010e3d5 (patch)
tree9f589b3cf0bcac63599f5c87ef1fdb9e96edc2a2 /server
parent22ebcced585da2a5e6aba6001f9e5cd2507d4069 (diff)
downloadvaadin-framework-277adf6142a4fa51a0aba42d9934ac0c0010e3d5.tar.gz
vaadin-framework-277adf6142a4fa51a0aba42d9934ac0c0010e3d5.zip
Set PushMode.AUTOMATIC as the default @Push value (#11653)
Change-Id: I3db47e1bd87e4e58a404b93a23da24270f764e14
Diffstat (limited to 'server')
-rw-r--r--server/src/com/vaadin/annotations/Push.java12
1 files changed, 9 insertions, 3 deletions
diff --git a/server/src/com/vaadin/annotations/Push.java b/server/src/com/vaadin/annotations/Push.java
index e97a1a34dd..58e70acf21 100644
--- a/server/src/com/vaadin/annotations/Push.java
+++ b/server/src/com/vaadin/annotations/Push.java
@@ -25,7 +25,12 @@ import com.vaadin.shared.communication.PushMode;
import com.vaadin.ui.UI;
/**
- * Defines a specific {@link PushMode} for a {@link UI}.
+ * Configures server push for a {@link UI}. Adding <code>@Push</code> to a UI
+ * class configures the UI for automatic push. If some other push mode is
+ * desired, it can be passed as a parameter, e.g.
+ * <code>@Push(PushMode.MANUAL)</code>.
+ *
+ * @see PushMode
*
* @author Vaadin Ltd.
* @since 7.1
@@ -34,10 +39,11 @@ import com.vaadin.ui.UI;
@Target(ElementType.TYPE)
public @interface Push {
/**
* Returns the {@link PushMode} to use for the annotated UI.
*
* @return the push mode to use
*/
- public PushMode value();
+ public PushMode value() default PushMode.AUTOMATIC;
}
@@ -34,10 +39,11 @@ import com.vaadin.ui.UI;
public @interface Push {
/**
- * Returns the {@link PushMode} to use for the annotated UI.
+ * Returns the {@link PushMode} to use for the annotated UI. The default
+ * push mode when this annotation is present is {@link PushMode#AUTOMATIC}.
*
* @return the push mode to use